/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
import { getHTML5TagProvider, getAngularTagProvider, getIonicTagProvider, collectTagsDefault, collectAttributesDefault } from '../parser/htmlTags';
import { getRazorTagProvider } from '../parser/razorTags';
var TagProviderCollection = /** @class */ (function () {
    function TagProviderCollection(tagProviders) {
        this._tagProviders = [
            getHTML5TagProvider(),
            getAngularTagProvider(),
            getIonicTagProvider(),
            getRazorTagProvider()
        ].concat(tagProviders);
    }
    Object.defineProperty(TagProviderCollection.prototype, "tagProviders", {
        get: function () {
            return this._tagProviders;
        },
        enumerable: true,
        configurable: true
    });
    TagProviderCollection.prototype.addTagProviders = function (tagProviders) {
        this._tagProviders = this._tagProviders.concat(tagProviders);
        return this;
    };
    return TagProviderCollection;
}());
export { TagProviderCollection };
var defaultCollection = new TagProviderCollection([]);
export function getAllTagProviders() {
    return defaultCollection.tagProviders;
}
export function addTagProviders(tagProviders) {
    return defaultCollection.addTagProviders(tagProviders);
}
export function addTags(tagSet) {
    var provider = {
        getId: function () { return 'userTagProvider'; },
        isApplicable: function () { return true; },
        collectTags: function (collector) { return collectTagsDefault(collector, tagSet); },
        collectAttributes: function (tag, collector) {
            collectAttributesDefault(tag, collector, tagSet, []);
        },
        collectValues: function (tag, attribute, collector) { }
    };
    defaultCollection.addTagProviders([provider]);
}
export function addAttributes(attributeSet) {
    var provider = {
        getId: function () { return 'userAttributeProvider'; },
        isApplicable: function () { return true; },
        collectTags: function (collector) { },
        collectAttributes: function (tag, collector) {
            collectAttributesDefault(tag, collector, {}, Object.keys(attributeSet));
        },
        collectValues: function (tag, attribute, collector) { }
    };
    defaultCollection.addTagProviders([provider]);
}
//# sourceMappingURL=tagProviders.js.map