(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "../parser/htmlTags", "../parser/razorTags"], factory);
    }
})(function (require, exports) {
    /*---------------------------------------------------------------------------------------------
     *  Copyright (c) Microsoft Corporation. All rights reserved.
     *  Licensed under the MIT License. See License.txt in the project root for license information.
     *--------------------------------------------------------------------------------------------*/
    'use strict';
    Object.defineProperty(exports, "__esModule", { value: true });
    var htmlTags_1 = require("../parser/htmlTags");
    var razorTags_1 = require("../parser/razorTags");
    var TagProviderCollection = /** @class */ (function () {
        function TagProviderCollection(tagProviders) {
            this._tagProviders = [
                htmlTags_1.getHTML5TagProvider(),
                htmlTags_1.getAngularTagProvider(),
                htmlTags_1.getIonicTagProvider(),
                razorTags_1.getRazorTagProvider()
            ].concat(tagProviders);
        }
        Object.defineProperty(TagProviderCollection.prototype, "tagProviders", {
            get: function () {
                return this._tagProviders;
            },
            enumerable: true,
            configurable: true
        });
        TagProviderCollection.prototype.addTagProviders = function (tagProviders) {
            this._tagProviders = this._tagProviders.concat(tagProviders);
            return this;
        };
        return TagProviderCollection;
    }());
    exports.TagProviderCollection = TagProviderCollection;
    var defaultCollection = new TagProviderCollection([]);
    function getAllTagProviders() {
        return defaultCollection.tagProviders;
    }
    exports.getAllTagProviders = getAllTagProviders;
    function addTagProviders(tagProviders) {
        return defaultCollection.addTagProviders(tagProviders);
    }
    exports.addTagProviders = addTagProviders;
    function addTags(tagSet) {
        var provider = {
            getId: function () { return 'userTagProvider'; },
            isApplicable: function () { return true; },
            collectTags: function (collector) { return htmlTags_1.collectTagsDefault(collector, tagSet); },
            collectAttributes: function (tag, collector) {
                htmlTags_1.collectAttributesDefault(tag, collector, tagSet, []);
            },
            collectValues: function (tag, attribute, collector) { }
        };
        defaultCollection.addTagProviders([provider]);
    }
    exports.addTags = addTags;
    function addAttributes(attributeSet) {
        var provider = {
            getId: function () { return 'userAttributeProvider'; },
            isApplicable: function () { return true; },
            collectTags: function (collector) { },
            collectAttributes: function (tag, collector) {
                htmlTags_1.collectAttributesDefault(tag, collector, {}, Object.keys(attributeSet));
            },
            collectValues: function (tag, attribute, collector) { }
        };
        defaultCollection.addTagProviders([provider]);
    }
    exports.addAttributes = addAttributes;
});
//# sourceMappingURL=tagProviders.js.map